======
lyceum
======


.. image:: https://img.shields.io/pypi/v/lyceum.svg
        :target: https://pypi.python.org/pypi/lyceum

.. image:: https://img.shields.io/travis/benabel/lyceum.svg
        :target: https://travis-ci.com/benabel/lyceum

.. image:: https://readthedocs.org/projects/lyceum-py/badge/?version=latest
        :target: https://lyceum.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Un paquet Python utile pour la programmation en lycée.


* Free software: ISC license
* Documentation: https://lyceum.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
